@@ -26,14 +26,25 @@ Common aliases for type hinting
 # stdlib
 import os
 import pathlib
+from decimal import Decimal
 from typing import Any, Type, Union
 
+#: Type hint for objects that represent filesystem paths.
 PathLike = Union[str, pathlib.Path, os.PathLike]
 
+AnyNumber = Union[float, int, Decimal]
+"""
+Type hint for numbers.
+
+.. versionchanged:: 0.4.6
+
+	Moved from :mod:`domdf_python_tools.pagesizes`
+"""
+
 
 def check_membership(obj: Any, type_: Union[Type, object]) -> bool:
 	"""
-	Check if the type of ``obj`` is one of the types in a :class:`typing.Union`, Sequence etc.
+	Check if the type of ``obj`` is one of the types in a :py:data:`typing.Union`, :typing.sequence:``Sequence`` etc.
 
 	:param obj: The object to check the type of
 	:param type_: A :class:`~typing.Type` that has members, such as a List, Union or Sequence.
